All Classes and Interfaces
Class
Description
Created by arcuri82 on 16-Sep-19.
handling response of actions which are executed in driver side
To authenticate a user, would need specific settings, like
specific values in the HTTP headers (eg, cookies)
this dto represents the info collected during sut booting
a code to categorize how a request achieved
Created by arcuri82 on 14-Jun-19.
Should we try to minimize or maximize the heuristic?
The type of extra heuristic.
Represents possible extra heuristics related to the code
execution and that do apply to all the reached testing targets.
process auth setting with endpoints in interfaces
dto is used to specify a seed for a field
which is typically used for specifying combined fields [CustomizedRequestValueDto#combinedKeyValuePairs]
eg, ID and corresponding passcode
dto is used to specify multiple seeds for a field.
mock object for database
a dto to collect info of param of endpoints to be tested
that is used by both core (for identifying genes) and driver (for endpoint invocation) sides
dto contains info which are used for handling post actions after the search
Created by arcuri82 on 05-Nov-18.
a dto to collect info of endpoints to be tested
that is used by both core (for identifying action) and driver (for endpoint invocation) sides
a list of RPC exception categories
contain exception info
a list of RPC exception type handled by evomaster
a dto to collect info of an RPC interface to be tested
that is sent to core
a dto to collect info of RPC problem to be tested
that is sent to core
a list of types we support for RPC
a dto represent RPC tests with executed results
A list of RPC types supported by EvoMaster
With different types, the handling might be different,
eg, create instance for input, exception handling and extraction.
this class is developed for handling invocation of schedule task at driver side.
this class is to save info after the schedule task is invoked
the info is used to track the status (eg, completed, running, failed) of the schedule task
TODO
As the schedule task can also be applied to other problem, eg, REST, GraphQL
in the future, need to refactor this class to other package
to reduce times of making http calls, all schedule tasks in a test will be handled one time.
this dto is used to save info on a sequence of invoked schedule tasks
seeded RPC action
seeded RPC test
a dto to collect info of type of the param of endpoints to be tested
Information about the "units" in the SUT.
In REST, when we have an error, at most we would see a HTTP
status code.