Class BootTimeInfoDto

java.lang.Object
org.evomaster.client.java.controller.api.dto.BootTimeInfoDto

public class BootTimeInfoDto extends Object
this dto represents the info collected during sut booting
  • Field Details

    • targets

      public List<TargetInfoDto> targets
      Info about the targets collected at boot-time
    • externalServicesDto

      public List<ExternalServiceInfoDto> externalServicesDto
      Information about the external services used inside the SUT
    • hostnameResolutionInfoDtos

      public List<HostnameResolutionInfoDto> hostnameResolutionInfoDtos
      Collections of hostnames collected through InetAddressReplacement
  • Constructor Details

    • BootTimeInfoDto

      public BootTimeInfoDto()