Class CustomizedRequestValueDto

java.lang.Object
org.evomaster.client.java.controller.api.dto.CustomizedRequestValueDto

public class CustomizedRequestValueDto extends Object
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    specify the value if it is only applicable to specified endpoints with corresponding annotation Note that it is nullable indicating that the value could be applied for all endpoints
    a set of fields and corresponding values in request note that [combinedKeyValuePairs] represents a candidate for a set of dependent keys
    a key with a set of candidate values note that [keyValues] represents a set of candidates for one key
    specify the value which is only applicable to the specified endpoint Note that it is nullable indicating that the value could be applied for endpoint with any name
    specify the value if it is only applicable to input with the specific type Note that it is nullable indicating that the value could be applied for all types of input params which contains field or param with name as key
  • Constructor Summary

    Constructors
    Constructor
    Description
     
  • Method Summary

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • combinedKeyValuePairs

      public List<KeyValuePairDto> combinedKeyValuePairs
      a set of fields and corresponding values in request note that [combinedKeyValuePairs] represents a candidate for a set of dependent keys
    • keyValues

      public KeyValuesDto keyValues
      a key with a set of candidate values note that [keyValues] represents a set of candidates for one key
    • annotationOnEndpoint

      public String annotationOnEndpoint
      specify the value if it is only applicable to specified endpoints with corresponding annotation Note that it is nullable indicating that the value could be applied for all endpoints
    • specificEndpointName

      public String specificEndpointName
      specify the value which is only applicable to the specified endpoint Note that it is nullable indicating that the value could be applied for endpoint with any name
    • specificRequestTypeName

      public String specificRequestTypeName
      specify the value if it is only applicable to input with the specific type Note that it is nullable indicating that the value could be applied for all types of input params which contains field or param with name as key
  • Constructor Details

    • CustomizedRequestValueDto

      public CustomizedRequestValueDto()