Class ExternalServiceInfoDto

java.lang.Object
org.evomaster.client.java.controller.api.dto.ExternalServiceInfoDto

public class ExternalServiceInfoDto extends Object
  • Field Details

    • remoteHostname

      public String remoteHostname
      Hostname of the remote service captured in the external call
    • protocol

      public String protocol
      Refers to the protocol used in the external service calls. Usually HTTP/S
    • remotePort

      public Integer remotePort
      Port of the remote service
  • Constructor Details

    • ExternalServiceInfoDto

      public ExternalServiceInfoDto()
    • ExternalServiceInfoDto

      public ExternalServiceInfoDto(String protocol, String remoteHostname, Integer remotePort)
  • Method Details