Class ExternalServiceMappingDto

java.lang.Object
org.evomaster.client.java.controller.api.dto.ExternalServiceMappingDto

public class ExternalServiceMappingDto extends Object
  • Field Details

    • remoteHostname

      public String remoteHostname
    • localIPAddress

      public String localIPAddress
    • signature

      public String signature
      Signature of the local mock service replaced the external web service. Signature is a unique identifier based on the [protocol], [remoteHostname], and [remotePort].
    • isActive

      public Boolean isActive
      Indicate the state of the mock server. Boolean True is when WireMock server is up and running.
  • Constructor Details

    • ExternalServiceMappingDto

      public ExternalServiceMappingDto()
    • ExternalServiceMappingDto

      public ExternalServiceMappingDto(String remoteHostname, String localIPAddress, String signature, Boolean isActive)
  • Method Details