Class ExtraHeuristicEntryDto

java.lang.Object
org.evomaster.client.java.controller.api.dto.ExtraHeuristicEntryDto
All Implemented Interfaces:
Serializable

public class ExtraHeuristicEntryDto extends Object implements Serializable
Created by arcuri82 on 14-Jun-19.
See Also:
  • Field Details

    • type

    • objective

    • id

      public String id
      An id representing this heuristics. For example, for SQL, it could be a SQL command
    • value

      public Double value
      The actual value of the heuristic
    • numberOfEvaluatedRecords

      public int numberOfEvaluatedRecords
      The number of records that were considered for computing the heuristic score. It might be rows for SQL queries and documents for NoSQL/Mongo queries.
    • extraHeuristicEvaluationFailure

      public boolean extraHeuristicEvaluationFailure
      Indicates whether the heuristic computation failed. If this is set to true, it means that an error or issue occurred during the evaluation of the heuristic score, and the value of the heuristic fails to the greatest value. When false, the heuristic was computed successfully. Example scenarios where this might be true include:
      • Database query errors (e.g., timeouts, syntax issues)
      • Parsing SQL query errors
      • Unsupported Mongo Query operators
  • Constructor Details