Enum ExtraHeuristicEntryDto.Objective

java.lang.Object
java.lang.Enum<ExtraHeuristicEntryDto.Objective>
org.evomaster.client.java.controller.api.dto.ExtraHeuristicEntryDto.Objective
All Implemented Interfaces:
Serializable, Comparable<ExtraHeuristicEntryDto.Objective>, java.lang.constant.Constable
Enclosing class:
ExtraHeuristicEntryDto

public static enum ExtraHeuristicEntryDto.Objective extends Enum<ExtraHeuristicEntryDto.Objective>
Should we try to minimize or maximize the heuristic?
  • Enum Constant Details

    • MINIMIZE_TO_ZERO

      public static final ExtraHeuristicEntryDto.Objective MINIMIZE_TO_ZERO
      The lower the better. Minimum is 0. It can be considered as a "distance" to minimize.
    • MAXIMIZE

      public static final ExtraHeuristicEntryDto.Objective MAXIMIZE
      The higher the better. Note: given x, we could rather considered the value 1/x to minimize. But that wouldn't work for negative x, and also would make debugging more difficult (ie better to look at the raw, non-transformed values).
  • Method Details

    • values

      public static ExtraHeuristicEntryDto.Objective[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static ExtraHeuristicEntryDto.Objective valueOf(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null