Class ExtraHeuristicsDto

java.lang.Object
org.evomaster.client.java.controller.api.dto.ExtraHeuristicsDto

public class ExtraHeuristicsDto extends Object
Represents possible extra heuristics related to the code execution and that do apply to all the reached testing targets. Example: rewarding SQL "select" operations that return non-empty sets
  • Field Details

    • heuristics

      public List<ExtraHeuristicEntryDto> heuristics
      List of extra heuristic values we want to optimize
    • sqlSqlExecutionsDto

      public org.evomaster.client.java.controller.api.dto.database.execution.SqlExecutionsDto sqlSqlExecutionsDto
    • mongoExecutionsDto

      public MongoExecutionsDto mongoExecutionsDto
    • redisExecutionsDto

      public RedisExecutionsDto redisExecutionsDto
  • Constructor Details

    • ExtraHeuristicsDto

      public ExtraHeuristicsDto()