Class KeyValuePairDto

java.lang.Object
org.evomaster.client.java.controller.api.dto.KeyValuePairDto

public class KeyValuePairDto extends Object
dto is used to specify a seed for a field which is typically used for specifying combined fields [CustomizedRequestValueDto#combinedKeyValuePairs] eg, ID and corresponding passcode
  • Field Details

    • fieldKey

      public String fieldKey
      field name which is related to auth in request
    • fieldValue

      public String fieldValue
      value of field for the key
  • Constructor Details

    • KeyValuePairDto

      public KeyValuePairDto()