Class MockDatabaseDto

java.lang.Object
org.evomaster.client.java.controller.api.dto.MockDatabaseDto

public class MockDatabaseDto extends Object
mock object for database
  • Field Details

    • appKey

      public String appKey
      a key refers to the Web API
    • databaseOrFrameworkType

      public String databaseOrFrameworkType
      it refers to a type of database or related framework, eg, mybatis nullable such info might be used by mocking technique for handling mock object
    • commandType

      public String commandType
      it refers to a type of SQL, eg, select nullable
    • sqlCommand

      public String sqlCommand
      sql command nullable
    • commandName

      public String commandName
      it refers to a command to be mocked not nullable
    • requests

      public String requests
      it represents what requests are accepted for enabling this mock object null represents any request is acceptable
    • response

      public String response
      response to return
    • responseFullType

      public String responseFullType
      it represents the datatype of response
    • responseFullTypeWithGeneric

      public String responseFullTypeWithGeneric
      explict type info with generics the info is used by evomaster
  • Constructor Details

    • MockDatabaseDto

      public MockDatabaseDto()
  • Method Details