Class RPCTestWithResultsDto
java.lang.Object
org.evomaster.client.java.controller.api.dto.RPCTestWithResultsDto
a dto represent RPC tests with executed results
-
Field Summary
FieldsModifier and TypeFieldDescriptiona list of RPC actionsa list of mocking handling for the testsa list of response correspoding to the actionsa list of sql handling for the tests -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
externalServiceDtos
a list of mocking handling for the tests -
sqlInsertions
a list of sql handling for the tests -
actions
a list of RPC actions -
responses
a list of response correspoding to the actions
-
-
Constructor Details
-
RPCTestWithResultsDto
public RPCTestWithResultsDto()
-