java.lang.Object
org.evomaster.client.java.controller.api.dto.SutInfoDto

public class SutInfoDto extends Object
  • Field Details

    • restProblem

      public RestProblemDto restProblem
      If the SUT is a RESTful API, here there will be the info on how to interact with it
    • graphQLProblem

      public GraphQLProblemDto graphQLProblem
      If the SUT is a GraphQL API, here there will be the info on how to interact with it
    • rpcProblem

      public RPCProblemDto rpcProblem
      If the SUT is a PRC-based service, here there will be the info on how to interact with it
    • webProblem

      public WebProblemDto webProblem
      If the SUT has a Web Frontend, here there will be the info on how to interact with it
    • isSutRunning

      public Boolean isSutRunning
      Whether the SUT is running or not
    • defaultOutputFormat

      public SutInfoDto.OutputFormat defaultOutputFormat
      When generating test cases for this SUT, specify the default preferred output format (eg JUnit 4 in Java)
    • baseUrlOfSUT

      public String baseUrlOfSUT
      The base URL of the running SUT (if any). E.g., "http://localhost:8080" It should only contain the protocol and the hostname/port
    • infoForAuthentication

      public List<AuthenticationDto> infoForAuthentication
      There is no way a testing system can guess passwords, even if given full access to the database storing them (ie, reversing hash values). As such, the SUT might need to provide a set of valid credentials
    • sqlSchemaDto

      public DbInfoDto sqlSchemaDto
      If the application is using a SQL database, then we need to know its schema to be able to do operations on it.
    • unitsInfoDto

      public UnitsInfoDto unitsInfoDto
      Information about the "units" in the SUT.
    • bootTimeInfoDto

      public BootTimeInfoDto bootTimeInfoDto
      info collected during SUT boot-time
    • errorMsg

      public List<String> errorMsg
      there might exist some errors which could be ignored for the moment in order to make evomaster still process test generations. however, such error should be handled properly in the future. to better view such errors, might show them on the core side
  • Constructor Details

    • SutInfoDto

      public SutInfoDto()