Class SutRunDto
java.lang.Object
org.evomaster.client.java.controller.api.dto.SutRunDto
-
Field Summary
FieldsModifier and TypeFieldDescriptionIf using SQL heuristics, enabled advanced versionWhether SQL heuristics should be computed.Whether SQL execution info should be saved.Specify which categories of Method Replacements to apply when classes are instrumented.Whether to reset the mock object with customized method this depends on the configuration from core side, ie, whether to apply customized method to handle external servicesWhether the internal state of the SUT should be resetWhether the SUT should be running -
Constructor Summary
ConstructorsConstructorDescriptionSutRunDto(Boolean run, Boolean resetState, Boolean resetCustomizedMethodForMockObject, Boolean calculateSqlHeuristics, Boolean extractSqlExecutionInfo, String methodReplacementCategories) SutRunDto(Boolean run, Boolean resetState, Boolean resetCustomizedMethodForMockObject, Boolean calculateSqlHeuristics, String methodReplacementCategories) -
Method Summary
-
Field Details
-
run
Whether the SUT should be running -
resetState
Whether the internal state of the SUT should be reset -
resetCustomizedMethodForMockObject
Whether to reset the mock object with customized method this depends on the configuration from core side, ie, whether to apply customized method to handle external services -
calculateSqlHeuristics
Whether SQL heuristics should be computed. Note: those can be very expensive -
advancedHeuristics
If using SQL heuristics, enabled advanced version -
extractSqlExecutionInfo
Whether SQL execution info should be saved. -
methodReplacementCategories
Specify which categories of Method Replacements to apply when classes are instrumented. Note that this applied once classes are loaded into JVM. Trying to change this after a class has been loaded will have no effect. This is a "," comma separated list of category names.
-
-
Constructor Details
-
SutRunDto
public SutRunDto() -
SutRunDto
-
SutRunDto
-