Class TestResultsDto
java.lang.Object
org.evomaster.client.java.controller.api.dto.TestResultsDto
-
Field Summary
FieldsModifier and TypeFieldDescriptionThis list is sorted based on the action indices -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
targets
-
additionalInfoList
This list is sorted based on the action indices -
extraHeuristics
-
-
Constructor Details
-
TestResultsDto
public TestResultsDto()
-