Class UnitsInfoDto

java.lang.Object
org.evomaster.client.java.controller.api.dto.UnitsInfoDto

public class UnitsInfoDto extends Object
Information about the "units" in the SUT. In case of OO languages like Java and Kotlin, those will be "classes" Created by arcuri82 on 27-Sep-19.
  • Field Details

    • unitNames

      public Set<String> unitNames
      Then name of all the units (eg classes) in the SUT
    • numberOfLines

      public int numberOfLines
      The total number of lines/statements/instructions in all units of the whole SUT
    • numberOfBranches

      public int numberOfBranches
      The total number of branches in all units of the whole SUT
    • numberOfReplacedMethodsInSut

      public int numberOfReplacedMethodsInSut
      Number of replaced method testability transformations. But only for SUT units.
    • numberOfReplacedMethodsInThirdParty

      public int numberOfReplacedMethodsInThirdParty
      Number of replaced method testability transformations. But only for third-party library units (ie all units not in the SUT).
    • numberOfTrackedMethods

      public int numberOfTrackedMethods
      Number of tracked methods. Those are special methods for which we explicitly keep track of how they are called (eg their inputs).
    • numberOfInstrumentedNumberComparisons

      public int numberOfInstrumentedNumberComparisons
      Number of cases in which numeric comparisons needed customized instrumentation (eg, needed on JVM for non-integer types)
    • parsedDtos

      public Map<String,String> parsedDtos
    • extractedSpecifiedDtos

      public Map<String,String> extractedSpecifiedDtos
      Key is DTO full name Value is OpenAPI object schema User might need to get schema of specific jvm dto classes and such jvm classes might not be read with jackson or gson this field is to collect a map of such specified jvm dto classes to their schema
    • extraDatabaseConstraintsDtos

      public List<ExtraConstraintsDto> extraDatabaseConstraintsDtos
      Extra information extracted for example from JPA entities
  • Constructor Details

    • UnitsInfoDto

      public UnitsInfoDto()