Package org.evomaster.client.java.controller.api.dto
package org.evomaster.client.java.controller.api.dto
-
ClassDescriptionCreated by arcuri82 on 16-Sep-19.handling response of actions which are executed in driver sidethis dto represents the info collected during sut bootinga code to categorize how a request achievedCreated by arcuri82 on 14-Jun-19.Should we try to minimize or maximize the heuristic?The type of extra heuristic.Represents possible extra heuristics related to the code execution and that do apply to all the reached testing targets.dto is used to specify a seed for a field which is typically used for specifying combined fields [CustomizedRequestValueDto#combinedKeyValuePairs] eg, ID and corresponding passcodedto is used to specify multiple seeds for a field.mock object for databasedto contains info which are used for handling post actions after the searcha dto represent RPC tests with executed resultsInformation about the "units" in the SUT.In REST, when we have an error, at most we would see a HTTP status code.