Serialized Form

  • Package org.evomaster.client.java.controller.api.dto

    • Class org.evomaster.client.java.controller.api.dto.ExtraHeuristicEntryDto

      class ExtraHeuristicEntryDto extends Object implements Serializable
      • Serialized Fields

        • extraHeuristicEvaluationFailure
          boolean extraHeuristicEvaluationFailure
          Indicates whether the heuristic computation failed. If this is set to true, it means that an error or issue occurred during the evaluation of the heuristic score, and the value of the heuristic fails to the greatest value. When false, the heuristic was computed successfully. Example scenarios where this might be true include:
          • Database query errors (e.g., timeouts, syntax issues)
          • Parsing SQL query errors
          • Unsupported Mongo Query operators
        • id
          String id
          An id representing this heuristics. For example, for SQL, it could be a SQL command
        • numberOfEvaluatedRecords
          int numberOfEvaluatedRecords
          The number of records that were considered for computing the heuristic score. It might be rows for SQL queries and documents for NoSQL/Mongo queries.
        • objective
          ExtraHeuristicEntryDto.Objective objective
        • type
          ExtraHeuristicEntryDto.Type type
        • value
          Double value
          The actual value of the heuristic