Class ActionDto
java.lang.Object
org.evomaster.client.java.controller.api.dto.ActionDto
Created by arcuri82 on 16-Sep-19.
-
Field Summary
FieldsModifier and TypeFieldDescriptionThis list of DTOs represents the external service mappings.The index of this action in the test.A list (possibly empty) of String values used in the action.Mapping of external service domain name and local address used for mocking.The name of the action, used to identify its type.info to execute an RPC action.List of skipped external services from handling inside core. -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
index
The index of this action in the test. note that schedule task is executed before this action Eg, in a test with 10 indices, the index would be between 0 and 9 -
name
The name of the action, used to identify its type. It is not unique. Eg, for REST, it could be something like VERB:PATH -
inputVariables
A list (possibly empty) of String values used in the action. This info can be used for different kinds of taint analysis, eg to check how such values are used in the SUT -
rpcCall
info to execute an RPC action. note that this is only used when handling RPC problem -
externalServiceMapping
This list of DTOs represents the external service mappings. Key: WireMock signature which is a string of protocol, hostname, and port. Value: Contains [ExternalServiceMappingDto] -
localAddressMapping
Mapping of external service domain name and local address used for mocking. -
skippedExternalServices
List of skipped external services from handling inside core. Information will be retrieved from [ProblemInfo] provided inside the driver.
-
-
Constructor Details
-
ActionDto
public ActionDto()
-