Class ActionResponseDto
java.lang.Object
org.evomaster.client.java.controller.api.dto.ActionResponseDto
handling response of actions which are executed in driver side
-
Field Summary
FieldsModifier and TypeFieldDescriptioncode for assertions currently, the assertion generation is processed on driver side based on response instance returned after the endpoint is invoked.representing a result categorized by user's specificationwith rpc, we need to return generated scripts and assertions then instead of only return msg, we return this dto with error msgrepresenting exception info if it occursfor RPC problem, its schema or mock object might be expanded during the searchThe index of this action which was executed in this test.an original response with json formata response from an RPC action.code for processing the action in generated test scripts, the action could be involved by either 1) executeRPCAction (a method in SutHandler) or 2) client.endpoint(args). -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
index
The index of this action which was executed in this test. -
rpcResponse
a response from an RPC action. note that this info is only used for RPC problem -
jsonResponse
an original response with json format -
testScript
code for processing the action in generated test scripts, the action could be involved by either 1) executeRPCAction (a method in SutHandler) or 2) client.endpoint(args). For 1), we could process it from core side, while for 2), now it is handled from driver side. this attribute is to enable 2) generation. -
assertionScript
code for assertions currently, the assertion generation is processed on driver side based on response instance returned after the endpoint is invoked. then this attribute contains a list of generated scripts for assertions on the response if it is not `void` -
exceptionInfoDto
representing exception info if it occurs -
customizedCallResultCode
representing a result categorized by user's specification -
error500Msg
with rpc, we need to return generated scripts and assertions then instead of only return msg, we return this dto with error msg -
expandInfo
for RPC problem, its schema or mock object might be expanded during the search
-
-
Constructor Details
-
ActionResponseDto
public ActionResponseDto()
-