Class BootTimeInfoDto
java.lang.Object
org.evomaster.client.java.controller.api.dto.BootTimeInfoDto
this dto represents the info collected during sut booting
-
Field Summary
FieldsModifier and TypeFieldDescriptionInformation about the external services used inside the SUTCollections of hostnames collected through InetAddressReplacementInfo about the targets collected at boot-time -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
targets
Info about the targets collected at boot-time -
externalServicesDto
Information about the external services used inside the SUT -
hostnameResolutionInfoDtos
Collections of hostnames collected through InetAddressReplacement
-
-
Constructor Details
-
BootTimeInfoDto
public BootTimeInfoDto()
-