Class CustomizedRequestValueDto
java.lang.Object
org.evomaster.client.java.controller.api.dto.CustomizedRequestValueDto
-
Field Summary
FieldsModifier and TypeFieldDescriptionspecify the value if it is only applicable to specified endpoints with corresponding annotation Note that it is nullable indicating that the value could be applied for all endpointsa set of fields and corresponding values in request note that [combinedKeyValuePairs] represents a candidate for a set of dependent keysa key with a set of candidate values note that [keyValues] represents a set of candidates for one keyspecify the value which is only applicable to the specified endpoint Note that it is nullable indicating that the value could be applied for endpoint with any namespecify the value if it is only applicable to input with the specific type Note that it is nullable indicating that the value could be applied for all types of input params which contains field or param with name as key -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
combinedKeyValuePairs
a set of fields and corresponding values in request note that [combinedKeyValuePairs] represents a candidate for a set of dependent keys -
keyValues
a key with a set of candidate values note that [keyValues] represents a set of candidates for one key -
annotationOnEndpoint
specify the value if it is only applicable to specified endpoints with corresponding annotation Note that it is nullable indicating that the value could be applied for all endpoints -
specificEndpointName
specify the value which is only applicable to the specified endpoint Note that it is nullable indicating that the value could be applied for endpoint with any name -
specificRequestTypeName
specify the value if it is only applicable to input with the specific type Note that it is nullable indicating that the value could be applied for all types of input params which contains field or param with name as key
-
-
Constructor Details
-
CustomizedRequestValueDto
public CustomizedRequestValueDto()
-