Class ExternalServiceInfoDto
java.lang.Object
org.evomaster.client.java.controller.api.dto.ExternalServiceInfoDto
-
Field Summary
FieldsModifier and TypeFieldDescriptionRefers to the protocol used in the external service calls.Hostname of the remote service captured in the external callPort of the remote service -
Constructor Summary
ConstructorsConstructorDescriptionExternalServiceInfoDto(String protocol, String remoteHostname, Integer remotePort) -
Method Summary
-
Field Details
-
remoteHostname
Hostname of the remote service captured in the external call -
protocol
Refers to the protocol used in the external service calls. Usually HTTP/S -
remotePort
Port of the remote service
-
-
Constructor Details
-
ExternalServiceInfoDto
public ExternalServiceInfoDto() -
ExternalServiceInfoDto
-
-
Method Details