Class ExternalServiceMappingDto
java.lang.Object
org.evomaster.client.java.controller.api.dto.ExternalServiceMappingDto
-
Field Summary
FieldsModifier and TypeFieldDescriptionIndicate the state of the mock server.Signature of the local mock service replaced the external web service. -
Constructor Summary
ConstructorsConstructorDescriptionExternalServiceMappingDto(String remoteHostname, String localIPAddress, String signature, Boolean isActive) -
Method Summary
-
Field Details
-
remoteHostname
-
localIPAddress
-
signature
Signature of the local mock service replaced the external web service. Signature is a unique identifier based on the [protocol], [remoteHostname], and [remotePort]. -
isActive
Indicate the state of the mock server. Boolean True is when WireMock server is up and running.
-
-
Constructor Details
-
ExternalServiceMappingDto
public ExternalServiceMappingDto() -
ExternalServiceMappingDto
-
-
Method Details