Class ExtraHeuristicEntryDto
java.lang.Object
org.evomaster.client.java.controller.api.dto.ExtraHeuristicEntryDto
- All Implemented Interfaces:
Serializable
Created by arcuri82 on 14-Jun-19.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic enumShould we try to minimize or maximize the heuristic?static enumThe type of extra heuristic. -
Field Summary
FieldsModifier and TypeFieldDescriptionbooleanIndicates whether the heuristic computation failed.An id representing this heuristics.intThe number of records that were considered for computing the heuristic score.The actual value of the heuristic -
Constructor Summary
ConstructorsConstructorDescriptionExtraHeuristicEntryDto(ExtraHeuristicEntryDto.Type type, ExtraHeuristicEntryDto.Objective objective, String id, Double value, int numberOfEvaluatedRecords, boolean heuristicEvaluationFailure) -
Method Summary
-
Field Details
-
type
-
objective
-
id
An id representing this heuristics. For example, for SQL, it could be a SQL command -
value
The actual value of the heuristic -
numberOfEvaluatedRecords
public int numberOfEvaluatedRecordsThe number of records that were considered for computing the heuristic score. It might be rows for SQL queries and documents for NoSQL/Mongo queries. -
extraHeuristicEvaluationFailure
public boolean extraHeuristicEvaluationFailureIndicates whether the heuristic computation failed. If this is set totrue, it means that an error or issue occurred during the evaluation of the heuristic score, and the value of the heuristic fails to the greatest value. Whenfalse, the heuristic was computed successfully. Example scenarios where this might betrueinclude:- Database query errors (e.g., timeouts, syntax issues)
- Parsing SQL query errors
- Unsupported Mongo Query operators
-
-
Constructor Details
-
ExtraHeuristicEntryDto
public ExtraHeuristicEntryDto() -
ExtraHeuristicEntryDto
public ExtraHeuristicEntryDto(ExtraHeuristicEntryDto.Type type, ExtraHeuristicEntryDto.Objective objective, String id, Double value, int numberOfEvaluatedRecords, boolean heuristicEvaluationFailure)
-