Class ExtraHeuristicsDto

java.lang.Object
org.evomaster.client.java.controller.api.dto.ExtraHeuristicsDto

public class ExtraHeuristicsDto extends Object
Represents possible extra heuristics related to the code execution and that do apply to all the reached testing targets. Example: rewarding SQL "select" operations that return non-empty sets
  • Field Details

  • Constructor Details

    • ExtraHeuristicsDto

      public ExtraHeuristicsDto()