Class ExtraHeuristicsDto
java.lang.Object
org.evomaster.client.java.controller.api.dto.ExtraHeuristicsDto
Represents possible extra heuristics related to the code
execution and that do apply to all the reached testing targets.
Example: rewarding SQL "select" operations that return non-empty sets
-
Field Summary
FieldsModifier and TypeFieldDescriptionList of extra heuristic values we want to optimize -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
heuristics
List of extra heuristic values we want to optimize -
sqlSqlExecutionsDto
-
mongoExecutionsDto
-
-
Constructor Details
-
ExtraHeuristicsDto
public ExtraHeuristicsDto()
-