Class KeyValuePairDto
java.lang.Object
org.evomaster.client.java.controller.api.dto.KeyValuePairDto
dto is used to specify a seed for a field
which is typically used for specifying combined fields [CustomizedRequestValueDto#combinedKeyValuePairs]
eg, ID and corresponding passcode
-
Field Summary
FieldsModifier and TypeFieldDescriptionfield name which is related to auth in requestvalue of field for the key -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
fieldKey
field name which is related to auth in request -
fieldValue
value of field for the key
-
-
Constructor Details
-
KeyValuePairDto
public KeyValuePairDto()
-