Class MockDatabaseDto
java.lang.Object
org.evomaster.client.java.controller.api.dto.MockDatabaseDto
mock object for database
-
Field Summary
FieldsModifier and TypeFieldDescriptiona key refers to the Web APIit refers to a command to be mocked not nullableit refers to a type of SQL, eg, select nullableit refers to a type of database or related framework, eg, mybatis nullable such info might be used by mocking technique for handling mock objectit represents what requests are accepted for enabling this mock object null represents any request is acceptableresponse to returnit represents the datatype of responseexplict type info with generics the info is used by evomastersql command nullable -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
appKey
a key refers to the Web API -
databaseOrFrameworkType
it refers to a type of database or related framework, eg, mybatis nullable such info might be used by mocking technique for handling mock object -
commandType
it refers to a type of SQL, eg, select nullable -
sqlCommand
sql command nullable -
commandName
it refers to a command to be mocked not nullable -
requests
it represents what requests are accepted for enabling this mock object null represents any request is acceptable -
response
response to return -
responseFullType
it represents the datatype of response -
responseFullTypeWithGeneric
explict type info with generics the info is used by evomaster
-
-
Constructor Details
-
MockDatabaseDto
public MockDatabaseDto()
-
-
Method Details
-
copy
-