Class SutInfoDto
java.lang.Object
org.evomaster.client.java.controller.api.dto.SutInfoDto
-
Nested Class Summary
Nested Classes -
Field Summary
FieldsModifier and TypeFieldDescriptionThe base URL of the running SUT (if any).info collected during SUT boot-timeWhen generating test cases for this SUT, specify the default preferred output format (eg JUnit 4 in Java)there might exist some errors which could be ignored for the moment in order to make evomaster still process test generations.If the SUT is a GraphQL API, here there will be the info on how to interact with itThere is no way a testing system can guess passwords, even if given full access to the database storing them (ie, reversing hash values).Whether the SUT is running or notIf the SUT is a RESTful API, here there will be the info on how to interact with itIf the SUT is a PRC-based service, here there will be the info on how to interact with itIf the application is using a SQL database, then we need to know its schema to be able to do operations on it.Information about the "units" in the SUT.If the SUT has a Web Frontend, here there will be the info on how to interact with it -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
restProblem
If the SUT is a RESTful API, here there will be the info on how to interact with it -
graphQLProblem
If the SUT is a GraphQL API, here there will be the info on how to interact with it -
rpcProblem
If the SUT is a PRC-based service, here there will be the info on how to interact with it -
webProblem
If the SUT has a Web Frontend, here there will be the info on how to interact with it -
isSutRunning
Whether the SUT is running or not -
defaultOutputFormat
When generating test cases for this SUT, specify the default preferred output format (eg JUnit 4 in Java) -
baseUrlOfSUT
The base URL of the running SUT (if any). E.g., "http://localhost:8080" It should only contain the protocol and the hostname/port -
infoForAuthentication
There is no way a testing system can guess passwords, even if given full access to the database storing them (ie, reversing hash values). As such, the SUT might need to provide a set of valid credentials -
sqlSchemaDto
If the application is using a SQL database, then we need to know its schema to be able to do operations on it. -
unitsInfoDto
Information about the "units" in the SUT. -
bootTimeInfoDto
info collected during SUT boot-time -
errorMsg
there might exist some errors which could be ignored for the moment in order to make evomaster still process test generations. however, such error should be handled properly in the future. to better view such errors, might show them on the core side
-
-
Constructor Details
-
SutInfoDto
public SutInfoDto()
-