java.lang.Object
org.evomaster.client.java.controller.api.dto.SutRunDto

public class SutRunDto extends Object
  • Field Details

    • run

      public Boolean run
      Whether the SUT should be running
    • resetState

      public Boolean resetState
      Whether the internal state of the SUT should be reset
    • resetCustomizedMethodForMockObject

      public Boolean resetCustomizedMethodForMockObject
      Whether to reset the mock object with customized method this depends on the configuration from core side, ie, whether to apply customized method to handle external services
    • calculateSqlHeuristics

      public Boolean calculateSqlHeuristics
      Whether SQL heuristics should be computed. Note: those can be very expensive
    • advancedHeuristics

      public Boolean advancedHeuristics
      If using SQL heuristics, enabled advanced version
    • extractSqlExecutionInfo

      public Boolean extractSqlExecutionInfo
      Whether SQL execution info should be saved.
    • methodReplacementCategories

      public String methodReplacementCategories
      Specify which categories of Method Replacements to apply when classes are instrumented. Note that this applied once classes are loaded into JVM. Trying to change this after a class has been loaded will have no effect. This is a "," comma separated list of category names.
  • Constructor Details

    • SutRunDto

      public SutRunDto()
    • SutRunDto

      public SutRunDto(Boolean run, Boolean resetState, Boolean resetCustomizedMethodForMockObject, Boolean calculateSqlHeuristics, Boolean extractSqlExecutionInfo, String methodReplacementCategories)
    • SutRunDto

      public SutRunDto(Boolean run, Boolean resetState, Boolean resetCustomizedMethodForMockObject, Boolean calculateSqlHeuristics, String methodReplacementCategories)