Class TargetInfoDto
java.lang.Object
org.evomaster.client.java.controller.api.dto.TargetInfoDto
-
Field Summary
FieldsModifier and TypeFieldDescriptionAn id identify the action that led to this fitness score for this testing target.A unique id for the target that is also descriptive for it.The id of the targetThe fitness value for this target, in [0,1], where 1 means covered -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
id
The id of the target -
descriptiveId
A unique id for the target that is also descriptive for it. Note: this string will usually be much longer than the numeric id. This field is optional: usually sent only the first time the target has been encountered, and will be mainly used for debugging reasons -
value
The fitness value for this target, in [0,1], where 1 means covered -
actionIndex
An id identify the action that led to this fitness score for this testing target. For example, it can be the index in the list representation of the test case. Can be negative if target was never reached. But this means thatvaluemust be 0
-
-
Constructor Details
-
TargetInfoDto
public TargetInfoDto()
-