Class UnitsInfoDto
java.lang.Object
org.evomaster.client.java.controller.api.dto.UnitsInfoDto
Information about the "units" in the SUT.
In case of OO languages like Java and Kotlin, those will be "classes"
Created by arcuri82 on 27-Sep-19.
-
Field Summary
FieldsModifier and TypeFieldDescriptionKey is DTO full name Value is OpenAPI object schema User might need to get schema of specific jvm dto classes and such jvm classes might not be read with jackson or gson this field is to collect a map of such specified jvm dto classes to their schemaExtra information extracted for example from JPA entitiesintThe total number of branches in all units of the whole SUTintNumber of cases in which numeric comparisons needed customized instrumentation (eg, needed on JVM for non-integer types)intThe total number of lines/statements/instructions in all units of the whole SUTintNumber of replaced method testability transformations.intNumber of replaced method testability transformations.intNumber of tracked methods.Then name of all the units (eg classes) in the SUT -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
unitNames
Then name of all the units (eg classes) in the SUT -
numberOfLines
public int numberOfLinesThe total number of lines/statements/instructions in all units of the whole SUT -
numberOfBranches
public int numberOfBranchesThe total number of branches in all units of the whole SUT -
numberOfReplacedMethodsInSut
public int numberOfReplacedMethodsInSutNumber of replaced method testability transformations. But only for SUT units. -
numberOfReplacedMethodsInThirdParty
public int numberOfReplacedMethodsInThirdPartyNumber of replaced method testability transformations. But only for third-party library units (ie all units not in the SUT). -
numberOfTrackedMethods
public int numberOfTrackedMethodsNumber of tracked methods. Those are special methods for which we explicitly keep track of how they are called (eg their inputs). -
numberOfInstrumentedNumberComparisons
public int numberOfInstrumentedNumberComparisonsNumber of cases in which numeric comparisons needed customized instrumentation (eg, needed on JVM for non-integer types) -
parsedDtos
-
extractedSpecifiedDtos
Key is DTO full name Value is OpenAPI object schema User might need to get schema of specific jvm dto classes and such jvm classes might not be read with jackson or gson this field is to collect a map of such specified jvm dto classes to their schema -
extraDatabaseConstraintsDtos
Extra information extracted for example from JPA entities
-
-
Constructor Details
-
UnitsInfoDto
public UnitsInfoDto()
-