Class WrappedResponseDto<T>
java.lang.Object
org.evomaster.client.java.controller.api.dto.WrappedResponseDto<T>
In REST, when we have an error, at most we would see a HTTP
status code.
But it can be very useful to get an actual description of the error.
So, it is a common practice to have "Wrapped Responses", which can
contain the error message (if any)
Created by arcuri82 on 05-Nov-18.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic <K> WrappedResponseDto<K>withData(K data) static WrappedResponseDto<?>static WrappedResponseDto<?>
-
Field Details
-
data
The actual payload we are sending and are "wrapping" here -
error
A message describing the error, if any. If this is not null, then "data" must be null.
-
-
Constructor Details
-
WrappedResponseDto
public WrappedResponseDto()
-
-
Method Details
-
withData
-
withNoData
-
withError
-